"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDark = exports.getContrastColor = exports.HSLToRGB = exports.RGBToHSL = void 0;
const values_js_1 = __importDefault(require("values.js"));
function RGBToHSL([r1, g1, b1]) {
    r1 /= 255;
    g1 /= 255;
    b1 /= 255;
    const max = Math.max(r1, g1, b1);
    const min = Math.min(r1, g1, b1);
    let h = 0;
    let s = 0;
    let l = (max + min) / 2;
    if (max !== min) {
        s = l < 0.5 ? (max - min) / (max + min) : (max - min) / (2 - max - min);
        h =
            max === r1
                ? (g1 - b1) / (max - min)
                : max === g1
                    ? 2 + (b1 - r1) / (max - min)
                    : 4 + (r1 - g1) / (max - min);
    }
    h *= 60;
    if (h < 0)
        h += 360;
    s *= 100;
    l *= 100;
    return [h, s, l];
}
exports.RGBToHSL = RGBToHSL;
function HSLToRGB([h, s, l]) {
    s /= 100;
    l /= 100;
    const c = (1 - Math.abs(2 * l - 1)) * s;
    const x = c * (1 - Math.abs(((h / 60) % 2) - 1));
    const m = l - c / 2;
    let r = 0;
    let g = 0;
    let b = 0;
    if (0 <= h && h < 60) {
        r = c;
        g = x;
        b = 0;
    }
    else if (60 <= h && h < 120) {
        r = x;
        g = c;
        b = 0;
    }
    else if (120 <= h && h < 180) {
        r = 0;
        g = c;
        b = x;
    }
    else if (180 <= h && h < 240) {
        r = 0;
        g = x;
        b = c;
    }
    else if (240 <= h && h < 300) {
        r = x;
        g = 0;
        b = c;
    }
    else if (300 <= h && h < 360) {
        r = c;
        g = 0;
        b = x;
    }
    r = Math.round((r + m) * 255);
    g = Math.round((g + m) * 255);
    b = Math.round((b + m) * 255);
    return [r, g, b];
}
exports.HSLToRGB = HSLToRGB;
function getContrastColor(rgb) {
    const hsl = RGBToHSL(rgb);
    hsl[0] = (hsl[0] + 180) % 360;
    const contrastRGB = HSLToRGB(hsl);
    return contrastRGB.map((v) => v.toString(16).padStart(2, '0')).join('');
}
exports.getContrastColor = getContrastColor;
const isDark = (color) => {
    return new values_js_1.default(color).getBrightness() <= 55;
};
exports.isDark = isDark;
